@@ -8,6 +8,7 @@ use Foorum::SUtils qw/schema/;
 use Foorum::Logger qw/error_log/;
 use Foorum::XUtils qw/tt2/;
 use File::Spec;
+use Date::Calc qw/Add_Delta_Days/;
 
 sub work {
     my $class = shift;
@@ -31,14 +32,14 @@ sub work {
     my $month = $atime[4] + 1;
     my $day   = $atime[3];
 
-    my @stats = $schema->resultset('Stat')
-        ->search( { date => \"> DATE_SUB(NOW(), INTERVAL 7 DAY)", } )->all;
+    ( $year, $month, $day ) = Add_Delta_Days( $year, $month, $day, -7 );
+    my $date = sprintf( "%04d%02d%02d", $year, $month, $day );
+
+    my @stats = $schema->resultset('Stat')->search( { date => \"> $date", } )->all;
 
     my $stats;
     foreach (@stats) {
-        my $date = $_->date;
-        $date =~ s/\-//isg;
-        $stats->{ $_->stat_key }->{$date} = $_->stat_value;
+        $stats->{ $_->stat_key }->{ $_->date } = $_->stat_value;
     }
 
     my $var = {
@@ -68,22 +69,28 @@ sub work {
 sub register_stat {
     my ( $schema, $table ) = @_;
 
+    my @atime = localtime();
+    my $year  = $atime[5] + 1900;
+    my $month = $atime[4] + 1;
+    my $day   = $atime[3];
+    my $now   = sprintf( "%04d%02d%02d", $year, $month, $day );
+
     my $stat_value = $schema->resultset($table)->count();
 
     my $stat_key = lc($table) . '_counts';
 
     my $dbh = $schema->storage->dbh;
 
-    my $sql = q~SELECT COUNT(*) FROM stat WHERE stat_key = ? AND date = NOW()~;
+    my $sql = qq~SELECT COUNT(*) FROM stat WHERE stat_key = ? AND date = $now~;
     my $sth = $dbh->prepare($sql);
     $sth->execute($stat_key);
 
     my ($count) = $sth->fetchrow_array;
 
     unless ($count) {
-        $sql = q~INSERT INTO stat SET stat_key = ?, stat_value = ?, date = NOW()~;
+        $sql = qq~INSERT INTO stat SET stat_key = ?, stat_value = ?, date = $now~;
     } else {
-        $sql = q~UPDATE stat SET stat_key = ?, date = NOW() WHERE stat_value = ?~;
+        $sql = qq~UPDATE stat SET stat_key = ?, date = $now WHERE stat_value = ?~;
     }
     $sth = $dbh->prepare($sql);
     $sth->execute( $stat_key, $stat_value );
